@@ -13,6 +13,7 @@ Library for working with the tor process.
     |- OperationFailed - Tor was unable to successfully complete the operation.
     |  |- UnsatisfiableRequest - Tor was unable to satisfy a valid request.
     |  |  +- CircuitExtensionFailed - Attempt to make or extend a circuit failed.
+    |  |- DescriptorUnavailable - The given relay descriptor is unavailable.
     |  +- InvalidRequest - Invalid request.
     |     +- InvalidArguments - Invalid request parameters.
     +- SocketError - Communication with the socket failed.
@@ -46,6 +47,7 @@ Library for working with the tor process.
   **HALT** or **TERM**      exit tor immediately
   **NEWNYM**                switch to new circuits, so new application requests don't share any circuits with old ones (this also clears our DNS cache)
   **CLEARDNSCACHE**         clears cached DNS results
+  **HEARTBEAT**             trigger a heartbeat log message
   ========================= ===========
 
 .. data:: Flag (enum)
@@ -53,6 +55,8 @@ Library for working with the tor process.
   Flag assigned to tor relays by the authorities to indicate various
   characteristics.
 
+  **Note:** The BADDIRECTORY flag was `removed from tor <https://gitweb.torproject.org/torspec.git/commit/dir-spec.txt?id=2f012f1>`_.
+
   ================= ===========
   Flag              Description
   ================= ===========
@@ -407,6 +411,19 @@ Library for working with the tor process.
   **FAILED**      we were unable to retrieve the descriptor
   =============== ===========
 
+.. data:: HSDescReason (enum)
+
+  Reason for the hidden service descriptor to fail to be fetched.
+
+  =================== ===========
+  HSDescReason        Description
+  =================== ===========
+  **BAD_DESC**        descriptor was unparseable
+  **QUERY_REJECTED**  hidden service directory refused to provide the descriptor
+  **NOT_FOUND**       descriptor with the given identifier wasn't found
+  **UNEXPECTED**      failure type is unknown
+  =================== ===========
+
 .. data:: HSAuth (enum)
 
   Type of authentication being used for a HS_DESC event.
@@ -421,7 +438,7 @@ Library for working with the tor process.
   ================= ===========
 """
 
-__version__ = '1.2.2'
+__version__ = '1.3.0'
 __author__ = 'Damian Johnson'
 __contact__ = 'atagar@torproject.org'
 __url__ = 'https://stem.torproject.org/'
@@ -443,6 +460,7 @@ __all__ = [
   'OperationFailed',
   'UnsatisfiableRequest',
   'CircuitExtensionFailed',
+  'DescriptorUnavailable',
   'InvalidRequest',
   'InvalidArguments',
   'SocketError',
@@ -458,6 +476,7 @@ __all__ = [
   'HiddenServiceState',
   'HSAuth',
   'HSDescAction',
+  'HSDescReason',
   'RelayEndReason',
   'StreamStatus',
   'StreamClosureReason',
@@ -522,6 +541,15 @@ class CircuitExtensionFailed(UnsatisfiableRequest):
     self.circ = circ
 
 
+class DescriptorUnavailable(OperationFailed):
+  """
+  Tor was unable to provide a descriptor for the given relay.
+  """
+
+  def __init__(self, message):
+    super(DescriptorUnavailable, self).__init__(message = message)
+
+
 class InvalidRequest(OperationFailed):
   """
   Exception raised when the request was invalid or malformed.
@@ -588,6 +616,7 @@ Signal = stem.util.enum.UppercaseEnum(
   'TERM',
   'NEWNYM',
   'CLEARDNSCACHE',
+  'HEARTBEAT',
 )
 
 CircStatus = stem.util.enum.UppercaseEnum(
@@ -774,6 +803,13 @@ HSDescAction = stem.util.enum.UppercaseEnum(
   'FAILED',
 )
 
+HSDescReason = stem.util.enum.UppercaseEnum(
+  'BAD_DESC',
+  'QUERY_REJECTED',
+  'NOT_FOUND',
+  'UNEXPECTED',
+)
+
 HSAuth = stem.util.enum.UppercaseEnum(
   'NO_AUTH',
   'BASIC_AUTH',
