@@ -555,7 +555,7 @@ def authenticate(controller, password = None, chroot_path = None, protocolinfo_r
 
   # iterating over AuthMethods so we can try them in this order
   for auth_type in (AuthMethod.NONE, AuthMethod.PASSWORD, AuthMethod.SAFECOOKIE, AuthMethod.COOKIE):
-    if not auth_type in auth_methods:
+    if auth_type not in auth_methods:
       continue
 
     try:
@@ -1012,7 +1012,7 @@ def get_protocolinfo(controller):
   # attempt to expand relative cookie paths
 
   if protocolinfo_response.cookie_path:
-    _expand_cookie_path(protocolinfo_response, stem.util.system.get_pid_by_name, 'tor')
+    _expand_cookie_path(protocolinfo_response, stem.util.system.pid_by_name, 'tor')
 
   # attempt to expand relative cookie paths via the control port or socket file
 
@@ -1023,10 +1023,10 @@ def get_protocolinfo(controller):
 
   if isinstance(control_socket, stem.socket.ControlPort):
     if control_socket.get_address() == '127.0.0.1':
-      pid_method = stem.util.system.get_pid_by_port
+      pid_method = stem.util.system.pid_by_port
       _expand_cookie_path(protocolinfo_response, pid_method, control_socket.get_port())
   elif isinstance(control_socket, stem.socket.ControlSocketFile):
-    pid_method = stem.util.system.get_pid_by_open_file
+    pid_method = stem.util.system.pid_by_open_file
     _expand_cookie_path(protocolinfo_response, pid_method, control_socket.get_socket_path())
 
   return protocolinfo_response
@@ -1102,7 +1102,7 @@ def _expand_cookie_path(protocolinfo_response, pid_resolver, pid_resolution_arg)
       if not tor_pid:
         raise IOError('pid lookup failed')
 
-      tor_cwd = stem.util.system.get_cwd(tor_pid)
+      tor_cwd = stem.util.system.cwd(tor_pid)
 
       if not tor_cwd:
         raise IOError('cwd lookup failed')
@@ -1110,9 +1110,9 @@ def _expand_cookie_path(protocolinfo_response, pid_resolver, pid_resolution_arg)
       cookie_path = stem.util.system.expand_path(cookie_path, tor_cwd)
     except IOError as exc:
       resolver_labels = {
-        stem.util.system.get_pid_by_name: ' by name',
-        stem.util.system.get_pid_by_port: ' by port',
-        stem.util.system.get_pid_by_open_file: ' by socket file',
+        stem.util.system.pid_by_name: ' by name',
+        stem.util.system.pid_by_port: ' by port',
+        stem.util.system.pid_by_open_file: ' by socket file',
       }
 
       pid_resolver_label = resolver_labels.get(pid_resolver, '')
