@@ -158,7 +158,7 @@ class Query(object):
 
   Tor provides quite a few different descriptor resources via its directory
   protocol (see section 4.2 and later of the `dir-spec
-  <https://gitweb.torproject.org/torspec.git/blob/HEAD:/dir-spec.txt>`_).
+  <https://gitweb.torproject.org/torspec.git/tree/dir-spec.txt>`_).
   Commonly useful ones include...
 
   ===================================== ===========
@@ -520,7 +520,7 @@ class DescriptorDownloader(object):
 
     :param str authority_v3ident: fingerprint of the authority key for which
       to get the consensus, see `'v3ident' in tor's config.c
-      <https://gitweb.torproject.org/tor.git/blob/f631b73:/src/or/config.c#l816>`_
+      <https://gitweb.torproject.org/tor.git/tree/src/or/config.c#n819>`_
       for the values.
     :param query_args: additional arguments for the
       :class:`~stem.descriptor.remote.Query` constructor
@@ -550,7 +550,7 @@ class DescriptorDownloader(object):
 
     resource = '/tor/status-vote/current/authority'
 
-    if not 'endpoint' in query_args:
+    if 'endpoint' not in query_args:
       query_args['endpoints'] = [(authority.address, authority.dir_port)]
 
     return self.query(resource + '.z', **query_args)
@@ -563,7 +563,7 @@ class DescriptorDownloader(object):
 
     :param str authority_v3idents: fingerprint or list of fingerprints of the
       authority keys, see `'v3ident' in tor's config.c
-      <https://gitweb.torproject.org/tor.git/blob/f631b73:/src/or/config.c#l816>`_
+      <https://gitweb.torproject.org/tor.git/tree/src/or/config.c#n819>`_
       for the values.
     :param query_args: additional arguments for the
       :class:`~stem.descriptor.remote.Query` constructor
@@ -605,10 +605,10 @@ class DescriptorDownloader(object):
     args = dict(self._default_args)
     args.update(query_args)
 
-    if not 'endpoints' in args:
+    if 'endpoints' not in args:
       args['endpoints'] = self._endpoints
 
-    if not 'fall_back_to_authority' in args:
+    if 'fall_back_to_authority' not in args:
       args['fall_back_to_authority'] = True
 
     return Query(
@@ -620,7 +620,7 @@ class DescriptorDownloader(object):
 class DirectoryAuthority(object):
   """
   Tor directory authority, a special type of relay `hardcoded into tor
-  <https://gitweb.torproject.org/tor.git/blob/f631b73:/src/or/config.c#l816>`_
+  <https://gitweb.torproject.org/tor.git/tree/src/or/config.c#n819>`_
   that enumerates the other relays within the network.
 
   At a very high level tor works as follows...
@@ -645,6 +645,9 @@ class DirectoryAuthority(object):
      network. They in turn use this to construct their circuits and use the
      network.
 
+  .. versionchanged:: 1.3.0
+     Added the is_bandwidth_authority attribute.
+
   :var str nickname: nickname of the authority
   :var str address: IP address of the authority, presently they're all IPv4 but
     this may not always be the case
@@ -654,11 +657,12 @@ class DirectoryAuthority(object):
   :var str v3ident: identity key fingerprint used to sign votes and consensus
   """
 
-  def __init__(self, nickname = None, address = None, or_port = None, dir_port = None, fingerprint = None, v3ident = None):
+  def __init__(self, nickname = None, address = None, or_port = None, dir_port = None, is_bandwidth_authority = False, fingerprint = None, v3ident = None):
     self.nickname = nickname
     self.address = address
     self.or_port = or_port
     self.dir_port = dir_port
+    self.is_bandwidth_authority = is_bandwidth_authority
     self.fingerprint = fingerprint
     self.v3ident = v3ident
 
@@ -669,6 +673,7 @@ DIRECTORY_AUTHORITIES = {
     address = '128.31.0.39',
     or_port = 9101,
     dir_port = 9131,
+    is_bandwidth_authority = True,
     fingerprint = '9695DFC35FFEB861329B9F1AB04C46397020CE31',
     v3ident = 'D586D18309DED4CD6D57C18FDB97EFA96D330566',
   ),
@@ -677,6 +682,7 @@ DIRECTORY_AUTHORITIES = {
     address = '86.59.21.38',
     or_port = 443,
     dir_port = 80,
+    is_bandwidth_authority = True,
     fingerprint = '847B1F850344D7876491A54892F904934E4EB85D',
     v3ident = '14C131DFC5C6F93646BE72FA1401C02A8DF2E8B4',
   ),
@@ -685,6 +691,7 @@ DIRECTORY_AUTHORITIES = {
     address = '194.109.206.212',
     or_port = 443,
     dir_port = 80,
+    is_bandwidth_authority = False,
     fingerprint = '7EA6EAD6FD83083C538F44038BBFA077587DD755',
     v3ident = 'E8A9C45EDE6D711294FADF8E7951F4DE6CA56B58',
   ),
@@ -693,22 +700,16 @@ DIRECTORY_AUTHORITIES = {
     address = '82.94.251.203',
     or_port = 443,
     dir_port = 80,
+    is_bandwidth_authority = False,
     fingerprint = '4A0CCD2DDC7995083D73F5D667100C8A5831F16D',
     v3ident = None,  # does not vote in the consensus
   ),
-  'turtles': DirectoryAuthority(
-    nickname = 'turtles',
-    address = '76.73.17.194',
-    or_port = 9090,
-    dir_port = 9030,
-    fingerprint = 'F397038ADC51336135E7B80BD99CA3844360292B',
-    v3ident = '27B6B5996C426270A5C95488AA5BCEB6BCC86956',
-  ),
   'gabelmoo': DirectoryAuthority(
     nickname = 'gabelmoo',
-    address = '212.112.245.170',
+    address = '131.188.40.189',
     or_port = 443,
     dir_port = 80,
+    is_bandwidth_authority = True,
     fingerprint = 'F2044413DAC2E02E3D6BCF4735A19BCA1DE97281',
     v3ident = 'ED03BB616EB2F60BEC80151114BB25CEF515B226',
   ),
@@ -717,6 +718,7 @@ DIRECTORY_AUTHORITIES = {
     address = '193.23.244.244',
     or_port = 443,
     dir_port = 80,
+    is_bandwidth_authority = False,
     fingerprint = '7BE683E65D48141321C5ED92F075C55364AC7123',
     v3ident = '585769C78764D58426B8B52B6651A5A71137189A',
   ),
@@ -725,6 +727,7 @@ DIRECTORY_AUTHORITIES = {
     address = '208.83.223.34',
     or_port = 80,
     dir_port = 443,
+    is_bandwidth_authority = False,
     fingerprint = '0AD3FA884D18F89EEA2D89C019379E0E7FD94417',
     v3ident = '80550987E1D626E3EBA5E5E75A458DE0626D088C',
   ),
@@ -733,6 +736,7 @@ DIRECTORY_AUTHORITIES = {
     address = '171.25.193.9',
     or_port = 80,
     dir_port = 443,
+    is_bandwidth_authority = True,
     fingerprint = 'BD6A829255CB08E66FBE7D3748363586E46B3810',
     v3ident = '49015F787433103580E3B66A1707A00E60F2D15B',
   ),
@@ -741,18 +745,27 @@ DIRECTORY_AUTHORITIES = {
     address = '154.35.32.5',
     or_port = 443,
     dir_port = 80,
+    is_bandwidth_authority = False,
     fingerprint = 'CF6D0AAFB385BE71B8E111FC5CFF4B47923733BC',
     v3ident = 'EFCBE720AB3A82B99F9E953CD5BF50F7EEFC7B97',
   ),
+  'longclaw': DirectoryAuthority(
+    nickname = 'longclaw',
+    address = '199.254.238.52',
+    or_port = 443,
+    dir_port = 80,
+    is_bandwidth_authority = True,
+    fingerprint = '74A910646BCEEFBCD2E874FC1DC997430F968145',
+    v3ident = '23D15D965BC35114467363C165C4F724B64B4F66',
+  ),
 }
 
 
 def get_authorities():
   """
-  Provides the Tor directory authority information as of **Tor commit 00bcc25
-  (8/27/13)**. The directory information hardcoded into Tor and occasionally
-  changes, so the information this provides might not necessarily match your
-  version of tor.
+  Provides the Tor directory authority information as of **Tor on 11/21/14**.
+  The directory information hardcoded into Tor and occasionally changes, so the
+  information this provides might not necessarily match your version of tor.
 
   :returns: dict of str nicknames to :class:`~stem.descriptor.remote.DirectoryAuthority` instances
   """
