@@ -4,10 +4,12 @@
 """
 Connection and networking based utility functions.
 
+**Module Overview:**
+
 ::
 
   get_connections - quieries the connections belonging to a given process
-  get_system_resolvers - provides connection resolution methods that are likely to be available
+  system_resolvers - provides connection resolution methods that are likely to be available
   port_usage - brief description of the common usage for a port
 
   is_valid_ipv4_address - checks if a string is a valid IPv4 address
@@ -130,7 +132,7 @@ RESOLVER_FILTER = {
 def get_connections(resolver, process_pid = None, process_name = None):
   """
   Retrieves a list of the current connections for a given process. The provides
-  a list of Connection instances, which have four attributes...
+  a list of Connection instances, which have five attributes...
 
     * local_address (str)
     * local_port (int)
@@ -172,7 +174,7 @@ def get_connections(resolver, process_pid = None, process_name = None):
     raise ValueError('%s resolution requires a pid' % resolver)
 
   if resolver == Resolver.PROC:
-    return [Connection(*conn) for conn in stem.util.proc.get_connections(process_pid)]
+    return [Connection(*conn) for conn in stem.util.proc.connections(process_pid)]
 
   resolver_command = RESOLVER_COMMAND[resolver].format(pid = process_pid)
 
@@ -230,12 +232,16 @@ def get_connections(resolver, process_pid = None, process_name = None):
   return connections
 
 
-def get_system_resolvers(system = None):
+def system_resolvers(system = None):
   """
   Provides the types of connection resolvers likely to be available on this platform.
 
   .. versionadded:: 1.1.0
 
+  .. versionchanged:: 1.3.0
+     Renamed from get_system_resolvers() to system_resolvers(). The old name
+     still works as an alias, but will be dropped in Stem version 2.0.0.
+
   :param str system: system to get resolvers for, this is determined by
     platform.system() if not provided
 
@@ -243,7 +249,10 @@ def get_system_resolvers(system = None):
   """
 
   if system is None:
-    system = platform.system()
+    if stem.util.system.is_gentoo():
+      system = 'Gentoo'
+    else:
+      system = platform.system()
 
   if system == 'Windows':
     resolvers = []
@@ -266,7 +275,7 @@ def get_system_resolvers(system = None):
 
   # proc resolution, by far, outperforms the others so defaults to this is able
 
-  if stem.util.proc.is_available():
+  if stem.util.proc.is_available() and os.access('/proc/net/tcp', os.R_OK) and os.access('/proc/net/udp', os.R_OK):
     resolvers = [Resolver.PROC] + resolvers
 
   return resolvers
@@ -333,7 +342,7 @@ def is_valid_ipv4_address(address):
   # checks if theres four period separated values
 
   if address.count('.') != 3:
-    return False
+     return False
 
   # checks that each value in the octet are decimal values between 0-255
   for entry in address.split('.'):
@@ -367,7 +376,7 @@ def is_valid_ipv6_address(address, allow_brackets = False):
 
   if colon_count > 7:
     return False  # too many groups
-  elif colon_count != 7 and not '::' in address:
+  elif colon_count != 7 and '::' not in address:
     return False  # not enough groups and none are collapsed
   elif address.count('::') > 1 or ':::' in address:
     return False  # multiple groupings of zeros can't be collapsed
@@ -389,24 +398,26 @@ def is_valid_port(entry, allow_zero = False):
   :returns: **True** if input is an integer and within the valid port range, **False** otherwise
   """
 
-  if isinstance(entry, list):
-    for port in entry:
-      if not is_valid_port(port, allow_zero):
-        return False
+  try:
+    value = int(entry)
 
-    return True
-  elif isinstance(entry, (bytes, unicode)):
-    if not entry.isdigit():
+    if str(value) != str(entry):
+      return False  # invalid leading char, e.g. space or zero
+    elif allow_zero and value == 0:
+      return True
+    else:
+      return value > 0 and value < 65536
+  except TypeError:
+    if isinstance(entry, (tuple, list)):
+      for port in entry:
+        if not is_valid_port(port, allow_zero):
+          return False
+
+      return True
+    else:
       return False
-    elif entry[0] == '0' and len(entry) > 1:
-      return False  # leading zeros, ex '001'
-
-    entry = int(entry)
-
-  if allow_zero and entry == 0:
-    return True
-
-  return entry > 0 and entry < 65536
+  except ValueError:
+    return False
 
 
 def is_private_address(address):
@@ -619,3 +630,9 @@ def _cryptovariables_equal(x, y):
   return (
     _hmac_sha256(CRYPTOVARIABLE_EQUALITY_COMPARISON_NONCE, x) ==
     _hmac_sha256(CRYPTOVARIABLE_EQUALITY_COMPARISON_NONCE, y))
+
+# TODO: drop with stem 2.x
+# We renamed our methods to drop a redundant 'get_*' prefix, so alias the old
+# names for backward compatability.
+
+get_system_resolvers = system_resolvers
