@@ -4,21 +4,31 @@
 """
 Toolkit for various string activity.
 
+.. versionchanged:: 1.3.0
+   Dropped the get_* prefix from several function names. The old names still
+   work, but are deprecated aliases.
+
 **Module Overview:**
 
 ::
 
-  get_size_label - human readable label for a number of bytes
-  get_time_label - human readable label for a number of seconds
-  get_time_labels - human readable labels for each time unit
-  get_short_time_label - condensed time label output
+  crop - shortens string to a given length
+
+  size_label - human readable label for a number of bytes
+  time_label - human readable label for a number of seconds
+  time_labels - human readable labels for each time unit
+  short_time_label - condensed time label output
   parse_short_time_label - seconds represented by a short time label
 """
 
 import codecs
 import datetime
+import re
+import sys
 
 import stem.prereq
+import stem.util.enum
+
 
 # label conversion tuples of the form...
 # (bits / bytes / seconds, short label, long label)
@@ -47,6 +57,8 @@ TIME_UNITS = (
   (1.0, 's', ' second'),
 )
 
+_timestamp_re = re.compile(r'(\d{4})-(\d{2})-(\d{2}) (\d{2}):(\d{2}):(\d{2})')
+
 if stem.prereq.is_python_3():
   def _to_bytes_impl(msg):
     if isinstance(msg, str):
@@ -131,7 +143,124 @@ def _to_camel_case(label, divider = '_', joiner = ' '):
   return joiner.join(words)
 
 
-def get_size_label(byte_count, decimal = 0, is_long = False, is_bytes = True):
+# This needs to be defined after _to_camel_case() to avoid a circular
+# dependency with the enum module.
+
+Ending = stem.util.enum.Enum('ELLIPSE', 'HYPHEN')
+
+
+def crop(msg, size, min_word_length = 4, min_crop = 0, ending = Ending.ELLIPSE, get_remainder = False):
+  """
+  Shortens a string to a given length.
+
+  If we crop content then a given ending is included (counting itself toward
+  the size limitation). This crops on word breaks so we only include a word if
+  we can display at least **min_word_length** characters of it.
+
+  If there isn't room for even a truncated single word (or one word plus the
+  ellipse if including those) then this provides an empty string.
+
+  If a cropped string ends with a comma or period then it's stripped (unless
+  we're providing the remainder back). For example...
+
+    >>> crop('This is a looooong message', 17)
+    'This is a looo...'
+
+    >>> crop('This is a looooong message', 12)
+    'This is a...'
+
+    >>> crop('This is a looooong message', 3)
+    ''
+
+  The whole point of this method is to provide human friendly croppings, and as
+  such details of how this works might change in the future. Callers should not
+  rely on the details of how this crops.
+
+  .. versionadded:: 1.3.0
+
+  :param str msg: text to be processed
+  :param int size: space available for text
+  :param int min_word_length: minimum characters before which a word is
+    dropped, requires whole word if **None**
+  :param int min_crop: minimum characters that must be dropped if a word is
+    cropped
+  :param Ending ending: type of ending used when truncating, no special
+    truncation is used if **None**
+  :param bool get_remainder: returns a tuple with the second part being the
+    cropped portion of the message
+
+  :returns: **str** of the text truncated to the given length
+  """
+
+  # checks if there's room for the whole message
+
+  if len(msg) <= size:
+    return (msg, '') if get_remainder else msg
+
+  if size < 0:
+    raise ValueError("Crop size can't be negative (received %i)" % size)
+  elif min_word_length and min_word_length < 0:
+    raise ValueError("Crop's min_word_length can't be negative (received %i)" % min_word_length)
+  elif min_crop < 0:
+    raise ValueError("Crop's min_crop can't be negative (received %i)" % min_crop)
+
+  # since we're cropping, the effective space available is less with an
+  # ellipse, and cropping words requires an extra space for hyphens
+
+  if ending == Ending.ELLIPSE:
+    size -= 3
+  elif min_word_length and ending == Ending.HYPHEN:
+    min_word_length += 1
+
+  if min_word_length is None:
+    min_word_length = sys.maxint
+
+  # checks if there isn't the minimum space needed to include anything
+
+  last_wordbreak = msg.rfind(' ', 0, size + 1)
+
+  if last_wordbreak == -1:
+    # we're splitting the first word
+
+    if size < min_word_length:
+      return ('', msg) if get_remainder else ''
+
+    include_crop = True
+  else:
+    last_wordbreak = len(msg[:last_wordbreak].rstrip())  # drops extra ending whitespaces
+    include_crop = size - last_wordbreak - 1 >= min_word_length
+
+  # if there's a max crop size then make sure we're cropping at least that many characters
+
+  if include_crop and min_crop:
+    next_wordbreak = msg.find(' ', size)
+
+    if next_wordbreak == -1:
+      next_wordbreak = len(msg)
+
+    include_crop = next_wordbreak - size + 1 >= min_crop
+
+  if include_crop:
+    return_msg, remainder = msg[:size], msg[size:]
+
+    if ending == Ending.HYPHEN:
+      remainder = return_msg[-1] + remainder
+      return_msg = return_msg[:-1].rstrip() + '-'
+  else:
+    return_msg, remainder = msg[:last_wordbreak], msg[last_wordbreak:]
+
+  # if this is ending with a comma or period then strip it off
+
+  if not get_remainder and return_msg and return_msg[-1] in (',', '.'):
+    return_msg = return_msg[:-1]
+
+  if ending == Ending.ELLIPSE:
+    return_msg = return_msg.rstrip() + '...'
+
+  return (return_msg, remainder) if get_remainder else return_msg
+
+
+def size_label(byte_count, decimal = 0, is_long = False, is_bytes = True):
   """
   Converts a number of bytes into a human readable label in its most
   significant units. For instance, 7500 bytes would return "7 KB". If the
@@ -141,13 +270,13 @@ def get_size_label(byte_count, decimal = 0, is_long = False, is_bytes = True):
 
   ::
 
-    >>> get_size_label(2000000)
+    >>> size_label(2000000)
     '1 MB'
 
-    >>> get_size_label(1050, 2)
+    >>> size_label(1050, 2)
     '1.02 KB'
 
-    >>> get_size_label(1050, 3, True)
+    >>> size_label(1050, 3, True)
     '1.025 Kilobytes'
 
   :param int byte_count: number of bytes to be converted
@@ -164,7 +293,7 @@ def get_size_label(byte_count, decimal = 0, is_long = False, is_bytes = True):
     return _get_label(SIZE_UNITS_BITS, byte_count, decimal, is_long)
 
 
-def get_time_label(seconds, decimal = 0, is_long = False):
+def time_label(seconds, decimal = 0, is_long = False):
   """
   Converts seconds into a time label truncated to its most significant units.
   For instance, 7500 seconds would return "2h". Units go up through days.
@@ -176,13 +305,13 @@ def get_time_label(seconds, decimal = 0, is_long = False):
 
   ::
 
-    >>> get_time_label(10000)
+    >>> time_label(10000)
     '2h'
 
-    >>> get_time_label(61, 1, True)
+    >>> time_label(61, 1, True)
     '1.0 minute'
 
-    >>> get_time_label(61, 2, True)
+    >>> time_label(61, 2, True)
     '1.01 minutes'
 
   :param int seconds: number of seconds to be converted
@@ -195,7 +324,7 @@ def get_time_label(seconds, decimal = 0, is_long = False):
   return _get_label(TIME_UNITS, seconds, decimal, is_long)
 
 
-def get_time_labels(seconds, is_long = False):
+def time_labels(seconds, is_long = False):
   """
   Provides a list of label conversions for each time unit, starting with its
   most significant units on down. Any counts that evaluate to zero are omitted.
@@ -203,10 +332,10 @@ def get_time_labels(seconds, is_long = False):
 
   ::
 
-    >>> get_time_labels(400)
+    >>> time_labels(400)
     ['6m', '40s']
 
-    >>> get_time_labels(3640, True)
+    >>> time_labels(3640, True)
     ['1 hour', '40 seconds']
 
   :param int seconds: number of seconds to be converted
@@ -225,17 +354,17 @@ def get_time_labels(seconds, is_long = False):
   return time_labels
 
 
-def get_short_time_label(seconds):
+def short_time_label(seconds):
   """
   Provides a time in the following format:
   [[dd-]hh:]mm:ss
 
   ::
 
-    >>> get_short_time_label(111)
+    >>> short_time_label(111)
     '01:51'
 
-    >>> get_short_time_label(544100)
+    >>> short_time_label(544100)
     '6-07:08:20'
 
   :param int seconds: number of seconds to be converted
@@ -310,6 +439,32 @@ def parse_short_time_label(label):
     raise ValueError('Non-numeric value in time entry: %s' % label)
 
 
+def _parse_timestamp(entry):
+  """
+  Parses the date and time that in format like like...
+
+  ::
+
+    2012-11-08 16:48:41
+
+  :param str entry: timestamp to be parsed
+
+  :returns: **datetime** for the time represented by the timestamp
+
+  :raises: **ValueError** if the timestamp is malformed
+  """
+
+  if not isinstance(entry, (str, unicode)):
+    raise ValueError('parse_timestamp() input must be a str, got a %s' % type(entry))
+
+  try:
+    time = [int(x) for x in _timestamp_re.match(entry).groups()]
+  except AttributeError:
+    raise ValueError("Expected timestamp in format YYYY-MM-DD HH:MM:ss but got " + entry)
+
+  return datetime.datetime(time[0], time[1], time[2], time[3], time[4], time[5])
+
+
 def _parse_iso_timestamp(entry):
   """
   Parses the ISO 8601 standard that provides for timestamps like...
@@ -320,12 +475,12 @@ def _parse_iso_timestamp(entry):
 
   :param str entry: timestamp to be parsed
 
-  :returns: datetime for the time represented by the timestamp
+  :returns: **datetime** for the time represented by the timestamp
 
-  :raises: ValueError if the timestamp is malformed
+  :raises: **ValueError** if the timestamp is malformed
   """
 
-  if not isinstance(entry, str):
+  if not isinstance(entry, (str, unicode)):
     raise ValueError('parse_iso_timestamp() input must be a str, got a %s' % type(entry))
 
   # based after suggestions from...
@@ -339,7 +494,12 @@ def _parse_iso_timestamp(entry):
   if len(microseconds) != 6 or not microseconds.isdigit():
     raise ValueError("timestamp's microseconds should be six digits")
 
-  timestamp = datetime.datetime.strptime(timestamp_str, "%Y-%m-%dT%H:%M:%S")
+  if timestamp_str[10] == 'T':
+    timestamp_str = timestamp_str[:10] + ' ' + timestamp_str[11:]
+  else:
+    raise ValueError("timestamp didn't contain delimeter 'T' between date and time")
+
+  timestamp = _parse_timestamp(timestamp_str)
   return timestamp + datetime.timedelta(microseconds = int(microseconds))
 
 
@@ -385,3 +545,12 @@ def _get_label(units, count, decimal, is_long):
         return count_label + long_label + ('s' if is_plural else '')
       else:
         return count_label + short_label
+
+# TODO: drop with stem 2.x
+# We renamed our methods to drop a redundant 'get_*' prefix, so alias the old
+# names for backward compatability.
+
+get_size_label = size_label
+get_time_label = time_label
+get_time_labels = time_labels
+get_short_time_label = short_time_label
