@@ -232,7 +232,7 @@ class TestController(unittest.TestCase):
 
       tor_options = test.runner.get_runner().get_options()
 
-      if not test.runner.Torrc.COOKIE in tor_options:
+      if test.runner.Torrc.COOKIE not in tor_options:
         controller.connect()
 
         if test.runner.Torrc.PASSWORD in tor_options:
@@ -455,6 +455,99 @@ class TestController(unittest.TestCase):
       self.assertEqual({}, controller.get_conf_map('', 'la-di-dah'))
       self.assertEqual({}, controller.get_conf_map([], 'la-di-dah'))
 
+  def test_hidden_services_conf(self):
+    """
+    Exercises the hidden service family of methods (get_hidden_service_conf,
+    set_hidden_service_conf, create_hidden_service, and remove_hidden_service).
+    """
+
+    if test.runner.require_control(self):
+      return
+
+    runner = test.runner.get_runner()
+
+    test_dir = runner.get_test_dir()
+    service1_path = os.path.join(test_dir, 'test_hidden_service1')
+    service2_path = os.path.join(test_dir, 'test_hidden_service2')
+    service3_path = os.path.join(test_dir, 'test_hidden_service3')
+    empty_service_path = os.path.join(test_dir, 'test_hidden_service_empty')
+
+    with runner.get_tor_controller() as controller:
+      try:
+        # initially we shouldn't be running any hidden services
+
+        self.assertEqual({}, controller.get_hidden_service_conf())
+
+        # try setting a blank config, shouldn't have any impact
+
+        controller.set_hidden_service_conf({})
+        self.assertEqual({}, controller.get_hidden_service_conf())
+
+        # create a hidden service
+
+        initialconf = {
+          service1_path: {
+            'HiddenServicePort': [
+              (8020, '127.0.0.1', 8020),
+              (8021, '127.0.0.1', 8021),
+            ],
+            'HiddenServiceVersion': '2',
+          },
+          service2_path: {
+            'HiddenServiceAuthorizeClient': 'stealth a, b',
+            'HiddenServicePort': [
+              (8030, '127.0.0.1', 8030),
+              (8031, '127.0.0.1', 8031),
+              (8032, '127.0.0.1', 8032),
+            ]
+          },
+          empty_service_path: {
+            'HiddenServicePort': []
+          }
+        }
+
+        controller.set_hidden_service_conf(initialconf)
+        self.assertEqual(initialconf, controller.get_hidden_service_conf())
+
+        # add already existing services, with/without explicit target
+
+        self.assertEqual(None, controller.create_hidden_service(service1_path, 8020))
+        self.assertEqual(None, controller.create_hidden_service(service1_path, 8021, target_port = 8021))
+        self.assertEqual(initialconf, controller.get_hidden_service_conf())
+
+        # add a new service, with/without explicit target
+
+        hs_path = os.path.join(os.getcwd(), service3_path)
+        hs_address1 = controller.create_hidden_service(hs_path, 8888).hostname
+        hs_address2 = controller.create_hidden_service(hs_path, 8989, target_port = 8021).hostname
+
+        self.assertEqual(hs_address1, hs_address2)
+        self.assertTrue(hs_address1.endswith('.onion'))
+
+        conf = controller.get_hidden_service_conf()
+        self.assertEqual(4, len(conf))
+        self.assertEqual(2, len(conf[hs_path]['HiddenServicePort']))
+
+        # remove a hidden service, the service dir should still be there
+
+        controller.remove_hidden_service(hs_path, 8888)
+        self.assertEqual(4, len(controller.get_hidden_service_conf()))
+
+        # remove a service completely, it should now be gone
+
+        controller.remove_hidden_service(hs_path, 8989)
+        self.assertEqual(3, len(controller.get_hidden_service_conf()))
+      finally:
+        controller.set_hidden_service_conf({})  # drop hidden services created during the test
+
+        # clean up the hidden service directories created as part of this test
+
+        for path in (service1_path, service2_path, service3_path):
+          try:
+            shutil.rmtree(path)
+          except:
+            pass
+
   def test_set_conf(self):
     """
     Exercises set_conf(), reset_conf(), and set_options() methods with valid
@@ -915,10 +1008,11 @@ class TestController(unittest.TestCase):
       return
     elif test.runner.require_version(self, Requirement.MICRODESCRIPTOR_IS_DEFAULT):
       return
+    elif test.runner.require_online(self):
+      return
 
     with test.runner.get_runner().get_tor_controller() as controller:
       # we should balk at invalid content
-      self.assertRaises(ValueError, controller.get_microdescriptor, None)
       self.assertRaises(ValueError, controller.get_microdescriptor, '')
       self.assertRaises(ValueError, controller.get_microdescriptor, 5)
       self.assertRaises(ValueError, controller.get_microdescriptor, 'z' * 30)
@@ -1023,10 +1117,11 @@ class TestController(unittest.TestCase):
 
     if test.runner.require_control(self):
       return
+    elif test.runner.require_online(self):
+      return
 
     with test.runner.get_runner().get_tor_controller() as controller:
       # we should balk at invalid content
-      self.assertRaises(ValueError, controller.get_network_status, None)
       self.assertRaises(ValueError, controller.get_network_status, '')
       self.assertRaises(ValueError, controller.get_network_status, 5)
       self.assertRaises(ValueError, controller.get_network_status, 'z' * 30)
@@ -1051,6 +1146,8 @@ class TestController(unittest.TestCase):
 
     if test.runner.require_control(self):
       return
+    elif test.runner.require_online(self):
+      return
 
     with runner.get_tor_controller() as controller:
       count = 0
