@@ -49,6 +49,12 @@ import stem.prereq
 import stem.response
 import stem.util.str_tools
 
+try:
+  # added in python 3.3
+  from unittest.mock import Mock, patch
+except ImportError:
+  from mock import Mock, patch
+
 CRYPTO_BLOB = """
 MIGJAoGBAJv5IIWQ+WDWYUdyA/0L8qbIkEVH/cwryZWoIaPAzINfrw1WfNZGtBmg
 skFtXhOHHqTRN4GPPrZsAIUOQGzQtGb66IQgT4tO/pj+P6QmSCCdTfhvGfgTCsC+
@@ -205,7 +211,7 @@ def get_all_combinations(attr, include_empty = False):
       # deduplicate, sort, and only provide if we haven't seen it yet
       item = tuple(sorted(set(item)))
 
-      if not item in seen:
+      if item not in seen:
         seen.add(item)
         yield item
 
@@ -298,7 +304,7 @@ def _get_descriptor_content(attr = None, exclude = (), header_template = (), foo
   attr = dict(attr)  # shallow copy since we're destructive
 
   for content, template in ((header_content, header_template),
-                           (footer_content, footer_template)):
+                            (footer_content, footer_template)):
     for keyword, value in template:
       if keyword in exclude:
         continue
@@ -347,7 +353,10 @@ def get_relay_server_descriptor(attr = None, exclude = (), content = False, sign
     if sign_content:
       desc_content = sign_descriptor_content(desc_content)
 
-    return stem.descriptor.server_descriptor.RelayDescriptor(desc_content, validate = True)
+    with patch('stem.descriptor.server_descriptor.RelayDescriptor._verify_digest', Mock()):
+      desc = stem.descriptor.server_descriptor.RelayDescriptor(desc_content, validate = True)
+
+    return desc
 
 
 def get_bridge_server_descriptor(attr = None, exclude = (), content = False):
