@@ -10,18 +10,13 @@ import test.runner
 
 from stem.descriptor.export import export_csv, export_csv_file
 
-from test.mocking import get_relay_server_descriptor, \
-                         get_bridge_server_descriptor
-
-try:
-  # added in python 3.3
-  from unittest.mock import Mock, patch
-except ImportError:
-  from mock import Mock, patch
+from test.mocking import (
+  get_relay_server_descriptor,
+  get_bridge_server_descriptor,
+)
 
 
 class TestExport(unittest.TestCase):
-  @patch('stem.descriptor.server_descriptor.RelayDescriptor._verify_digest', Mock())
   def test_minimal_descriptor(self):
     """
     Exports a single minimal tor server descriptor.
@@ -42,7 +37,6 @@ class TestExport(unittest.TestCase):
     expected = 'nickname,address,published\n' + expected
     self.assertEquals(expected, desc_csv)
 
-  @patch('stem.descriptor.server_descriptor.RelayDescriptor._verify_digest', Mock())
   def test_multiple_descriptors(self):
     """
     Exports multiple descriptors, making sure that we get them back in the same
@@ -59,7 +53,6 @@ class TestExport(unittest.TestCase):
     expected = '\n'.join(nicknames) + '\n'
     self.assertEqual(expected, export_csv(descriptors, included_fields = ('nickname',), header = False))
 
-  @patch('stem.descriptor.server_descriptor.RelayDescriptor._verify_digest', Mock())
   def test_file_output(self):
     """
     Basic test for the export_csv_file() function, checking that it provides
@@ -74,7 +67,6 @@ class TestExport(unittest.TestCase):
 
     self.assertEqual(desc_csv, csv_buffer.getvalue())
 
-  @patch('stem.descriptor.server_descriptor.RelayDescriptor._verify_digest', Mock())
   def test_excludes_private_attr(self):
     """
     Checks that the default attributes for our csv output doesn't include private fields.
@@ -99,7 +91,6 @@ class TestExport(unittest.TestCase):
 
     self.assertEquals('', export_csv([]))
 
-  @patch('stem.descriptor.server_descriptor.RelayDescriptor._verify_digest', Mock())
   def test_invalid_attributes(self):
     """
     Attempts to make a csv with attributes that don't exist.
@@ -108,7 +99,6 @@ class TestExport(unittest.TestCase):
     desc = get_relay_server_descriptor()
     self.assertRaises(ValueError, export_csv, desc, ('nickname', 'blarg!'))
 
-  @patch('stem.descriptor.server_descriptor.RelayDescriptor._verify_digest', Mock())
   def test_multiple_descriptor_types(self):
     """
     Attempts to make a csv with multiple descriptor types.
