@@ -17,6 +17,13 @@ try:
 except ImportError:
   from mock import Mock, patch
 
+OVER_THE_RIVER_OUTPUT = """\
+ * Connecting to tor
+ * Creating our hidden service in /home/atagar/.tor/hello_world
+ * Our service is available at uxiuaxejc3sxrb6i.onion, press ctrl+c to quit
+ * Shutting down our hidden service
+"""
+
 MIRROR_MIRROR_OUTPUT = """\
 1. speedyexit (102.13 KB/s)
 2. speedyexit (102.13 KB/s)
@@ -48,6 +55,72 @@ class TestTutorial(unittest.TestCase):
     tutorial_example()
     self.assertEqual('My Tor relay has read 33406 bytes and written 29649.\n', stdout_mock.getvalue())
 
+  @patch('sys.stdout', new_callable = StringIO.StringIO)
+  @patch('shutil.rmtree')
+  @patch('stem.control.Controller.from_port', spec = Controller)
+  def test_over_the_river(self, from_port_mock, rmtree_mock, stdout_mock):
+    def tutorial_example(app):
+      import os
+      import shutil
+
+      from stem.control import Controller
+
+      @app.route('/')
+      def index():
+        return "<h1>Hi Grandma!</h1>"
+
+      print ' * Connecting to tor'
+
+      with Controller.from_port() as controller:
+        controller.authenticate()
+
+        # All hidden services have a directory on disk. Lets put ours in tor's data
+        # directory.
+
+        hidden_service_dir = os.path.join(controller.get_conf('DataDirectory', '/tmp'), 'hello_world')
+
+        # Create a hidden service where visitors of port 80 get redirected to local
+        # port 5000 (this is where flask runs by default).
+
+        print " * Creating our hidden service in %s" % hidden_service_dir
+        result = controller.create_hidden_service(hidden_service_dir, 80, target_port = 5000)
+
+        # The hostname is only available we can read the hidden service directory.
+        # This requires us to be running with the same user as tor.
+
+        if result.hostname:
+          print " * Our service is available at %s, press ctrl+c to quit" % result.hostname
+        else:
+          print " * Unable to determine our service's hostname, probably due to being unable to read the hidden service directory"
+
+        try:
+          app.run()
+        finally:
+          # Shut down the hidden service and clean it off disk. Note that you *don't*
+          # want to delete the hidden service directory if you'd like to have this
+          # same *.onion address in the future.
+
+          print " * Shutting down our hidden service"
+          controller.remove_hidden_service(hidden_service_dir)
+          shutil.rmtree(hidden_service_dir)
+
+    flask_mock = Mock()
+
+    hidden_service_data = Mock()
+    hidden_service_data.hostname = 'uxiuaxejc3sxrb6i.onion'
+
+    controller = from_port_mock().__enter__()
+    controller.get_conf.return_value = '/home/atagar/.tor'
+    controller.create_hidden_service.return_value = hidden_service_data
+
+    tutorial_example(flask_mock)
+
+    controller.get_conf.assert_called_once_with('DataDirectory', '/tmp')
+    controller.create_hidden_service.assert_called_once_with('/home/atagar/.tor/hello_world', 80, target_port = 5000)
+    rmtree_mock.assert_called_once_with('/home/atagar/.tor/hello_world')
+
+    self.assertEqual(OVER_THE_RIVER_OUTPUT, stdout_mock.getvalue())
+
   @patch('sys.stdout', new_callable = StringIO.StringIO)
   @patch('stem.descriptor.remote.DescriptorDownloader')
   def test_mirror_mirror_on_the_wall_1(self, downloader_mock, stdout_mock):
@@ -107,7 +180,6 @@ class TestTutorial(unittest.TestCase):
 
   @patch('sys.stdout', new_callable = StringIO.StringIO)
   @patch('stem.descriptor.reader.DescriptorReader', spec = DescriptorReader)
-  @patch('stem.descriptor.server_descriptor.RelayDescriptor._verify_digest', Mock())
   def test_mirror_mirror_on_the_wall_4(self, reader_mock, stdout_mock):
     def tutorial_example():
       from stem.descriptor.reader import DescriptorReader
@@ -152,7 +224,7 @@ class TestTutorial(unittest.TestCase):
 
       for bw_value in sorted(bw_to_relay.keys(), reverse = True):
         for nickname in bw_to_relay[bw_value]:
-          print '%i. %s (%s/s)' % (count, nickname, str_tools.get_size_label(bw_value, 2))
+          print '%i. %s (%s/s)' % (count, nickname, str_tools.size_label(bw_value, 2))
           count += 1
 
           if count > 15:
