@@ -53,6 +53,19 @@ firefox   20586 atagar   66u  IPv4  5765353      0t0  TCP 192.168.0.1:47486->62.
 firefox   20586 atagar   71u  IPv4 13094989      0t0  TCP 192.168.0.1:43762->182.3.10.42:443 (CLOSE_WAIT)
 """
 
+LSOF_OUTPUT_OSX = """\
+tor       129 atagar    4u  IPv4 0xffffff3527af0500      0t0  TCP 127.0.0.1:9051 (LISTEN)
+tor       129 atagar    5u  IPv4 0xffffff363af9de40      0t0  TCP 192.168.1.10:9090 (LISTEN)
+tor       129 atagar    6u  IPv4 0xffffff306a960a40      0t0  TCP 192.168.1.10:9091 (LISTEN)
+tor       129 atagar    8u  IPv6 0xffffff13f5575a98      0t0  UDP *:48718
+tor       129 atagar    9u  IPv6 0xffffff1b2273a178      0t0  UDP *:48714
+tor       129 atagar   10u  IPv6 0xffffff1b473a9758      0t0  UDP *:48716
+tor       129 atagar   11u  IPv6 0xffffff1b5733aa48      0t0  UDP *:48719
+tor       129 atagar   12u  IPv4 0xffffff1cc6dd0160      0t0  TCP 192.168.1.20:9090->38.229.79.2:14010 (ESTABLISHED)
+tor       129 atagar   22u  IPv4 0xffffff35c9125500      0t0  TCP 192.168.1.20:9090->68.169.35.102:14815 (ESTABLISHED)
+tor       129 atagar   23u  IPv4 0xffffff3236168160      0t0  TCP 192.168.1.20:9090->62.135.16.134:14456 (ESTABLISHED)
+"""
+
 SOCKSTAT_OUTPUT = """\
 USER     PROCESS              PID      PROTO  SOURCE ADDRESS            FOREIGN ADDRESS           STATE
 atagar   ubuntu-geoip-pr      2164     tcp4   192.168.0.1:55395         141.18.34.33:80           CLOSE_WAIT
@@ -94,34 +107,45 @@ BSD_PROCSTAT_OUTPUT = """\
 class TestConnection(unittest.TestCase):
   @patch('stem.util.system.is_available')
   @patch('stem.util.proc.is_available')
-  def test_get_system_resolvers(self, proc_mock, is_available_mock):
+  def test_system_resolvers(self, proc_mock, is_available_mock):
     """
-    Checks the get_system_resolvers function.
+    Checks the system_resolvers function.
     """
 
     is_available_mock.return_value = True
     proc_mock.return_value = False
 
-    self.assertEqual([], stem.util.connection.get_system_resolvers('Windows'))
-    self.assertEqual([Resolver.LSOF], stem.util.connection.get_system_resolvers('Darwin'))
-    self.assertEqual([Resolver.LSOF], stem.util.connection.get_system_resolvers('OpenBSD'))
-    self.assertEqual([Resolver.BSD_SOCKSTAT, Resolver.BSD_PROCSTAT, Resolver.LSOF], stem.util.connection.get_system_resolvers('FreeBSD'))
-    self.assertEqual([Resolver.NETSTAT, Resolver.SOCKSTAT, Resolver.LSOF, Resolver.SS], stem.util.connection.get_system_resolvers('Linux'))
+    self.assertEqual([], stem.util.connection.system_resolvers('Windows'))
+    self.assertEqual([Resolver.LSOF], stem.util.connection.system_resolvers('Darwin'))
+    self.assertEqual([Resolver.LSOF], stem.util.connection.system_resolvers('OpenBSD'))
+    self.assertEqual([Resolver.BSD_SOCKSTAT, Resolver.BSD_PROCSTAT, Resolver.LSOF], stem.util.connection.system_resolvers('FreeBSD'))
+    self.assertEqual([Resolver.NETSTAT, Resolver.SOCKSTAT, Resolver.LSOF, Resolver.SS], stem.util.connection.system_resolvers('Linux'))
 
     proc_mock.return_value = True
-    self.assertEqual([Resolver.PROC, Resolver.NETSTAT, Resolver.SOCKSTAT, Resolver.LSOF, Resolver.SS], stem.util.connection.get_system_resolvers('Linux'))
+    self.assertEqual([Resolver.PROC, Resolver.NETSTAT, Resolver.SOCKSTAT, Resolver.LSOF, Resolver.SS], stem.util.connection.system_resolvers('Linux'))
 
     # check that calling without an argument is equivilant to calling for this
     # platform
 
-    self.assertEqual(stem.util.connection.get_system_resolvers(platform.system()), stem.util.connection.get_system_resolvers())
+    self.assertEqual(stem.util.connection.system_resolvers(platform.system()), stem.util.connection.system_resolvers())
 
     # check that lacking commands in our PATH drops them from the results
 
     is_available_mock.return_value = False
-    self.assertEqual([Resolver.PROC], stem.util.connection.get_system_resolvers('Linux'))
+    self.assertEqual([Resolver.PROC], stem.util.connection.system_resolvers('Linux'))
 
-  @patch('stem.util.proc.get_connections')
+  def test_port_usage(self):
+    """
+    Check that port_usage can load our config and provide the expected results.
+    """
+
+    self.assertEqual('HTTP', stem.util.connection.port_usage(80))
+    self.assertEqual('HTTP', stem.util.connection.port_usage('80'))  # query with a string
+    self.assertEqual('BitTorrent', stem.util.connection.port_usage(6881))  # min and max value of a range
+    self.assertEqual('BitTorrent', stem.util.connection.port_usage(6999))
+    self.assertEqual(None, stem.util.connection.port_usage(30000))  # unrecognized port
+
+  @patch('stem.util.proc.connections')
   def test_get_connections_by_proc(self, proc_mock):
     """
     Checks the get_connections function with the proc resolver.
@@ -196,6 +220,23 @@ class TestConnection(unittest.TestCase):
     call_mock.side_effect = OSError('Unable to call lsof')
     self.assertRaises(IOError, stem.util.connection.get_connections, Resolver.LSOF, process_pid = 1111)
 
+  @patch('stem.util.system.call')
+  def test_get_connections_by_lsof_osx(self, call_mock):
+    """
+    Checks the get_connections function with the lsof resolver on OSX. This
+    only includes entries for the tor process.
+    """
+
+    call_mock.return_value = LSOF_OUTPUT_OSX.split('\n')
+
+    expected = [
+      Connection('192.168.1.20', 9090, '38.229.79.2', 14010, 'tcp'),
+      Connection('192.168.1.20', 9090, '68.169.35.102', 14815, 'tcp'),
+      Connection('192.168.1.20', 9090, '62.135.16.134', 14456, 'tcp'),
+    ]
+
+    self.assertEqual(expected, stem.util.connection.get_connections(Resolver.LSOF, process_pid = 129, process_name = 'tor'))
+
   @patch('stem.util.system.call')
   def test_get_connections_by_sockstat(self, call_mock):
     """
@@ -265,19 +306,19 @@ class TestConnection(unittest.TestCase):
     """
 
     valid_addresses = (
-      "0.0.0.0",
-      "1.2.3.4",
-      "192.168.0.1",
-      "255.255.255.255",
+      '0.0.0.0',
+      '1.2.3.4',
+      '192.168.0.1',
+      '255.255.255.255',
     )
 
     invalid_addresses = (
-      "0.0.00.0",
-      "0.0.0",
-      "1.2.3.256",
-      "1.2.3.-1",
-      "0.0.0.a",
-      "a.b.c.d",
+      '0.0.00.0',
+      '0.0.0',
+      '1.2.3.256',
+      '1.2.3.-1',
+      '0.0.0.a',
+      'a.b.c.d',
     )
 
     for address in valid_addresses:
@@ -292,19 +333,19 @@ class TestConnection(unittest.TestCase):
     """
 
     valid_addresses = (
-      "fe80:0000:0000:0000:0202:b3ff:fe1e:8329",
-      "fe80:0:0:0:202:b3ff:fe1e:8329",
-      "fe80::202:b3ff:fe1e:8329",
-      "::",
+      'fe80:0000:0000:0000:0202:b3ff:fe1e:8329',
+      'fe80:0:0:0:202:b3ff:fe1e:8329',
+      'fe80::202:b3ff:fe1e:8329',
+      '::',
     )
 
     invalid_addresses = (
-      "fe80:0000:0000:0000:0202:b3ff:fe1e:829g",
-      "fe80:0000:0000:0000:0202:b3ff:fe1e: 8329",
-      "2001:db8::aaaa::1",
-      ":::",
-      ":",
-      "",
+      'fe80:0000:0000:0000:0202:b3ff:fe1e:829g',
+      'fe80:0000:0000:0000:0202:b3ff:fe1e: 8329',
+      '2001:db8::aaaa::1',
+      ':::',
+      ':',
+      '',
     )
 
     for address in valid_addresses:
@@ -318,8 +359,8 @@ class TestConnection(unittest.TestCase):
     Checks the is_valid_port function.
     """
 
-    valid_ports = (1, "1", 1234, "1234", 65535, "65535")
-    invalid_ports = (0, "0", 65536, "65536", "abc", "*", " 15", "01")
+    valid_ports = (1, '1', 1234, '1234', 65535, '65535', [1, '2'])
+    invalid_ports = (0, '0', 65536, '65536', 'abc', '*', ' 15', '01', True, {})
 
     for port in valid_ports:
       self.assertTrue(stem.util.connection.is_valid_port(port))
@@ -328,7 +369,7 @@ class TestConnection(unittest.TestCase):
       self.assertFalse(stem.util.connection.is_valid_port(port))
 
     self.assertTrue(stem.util.connection.is_valid_port(0, allow_zero = True))
-    self.assertTrue(stem.util.connection.is_valid_port("0", allow_zero = True))
+    self.assertTrue(stem.util.connection.is_valid_port('0', allow_zero = True))
 
   def test_is_private_address(self):
     """
@@ -356,26 +397,26 @@ class TestConnection(unittest.TestCase):
     """
 
     test_values = {
-      "2001:db8::ff00:42:8329": "2001:0db8:0000:0000:0000:ff00:0042:8329",
-      "::": "0000:0000:0000:0000:0000:0000:0000:0000",
-      "::1": "0000:0000:0000:0000:0000:0000:0000:0001",
-      "1::1": "0001:0000:0000:0000:0000:0000:0000:0001",
+      '2001:db8::ff00:42:8329': '2001:0db8:0000:0000:0000:ff00:0042:8329',
+      '::': '0000:0000:0000:0000:0000:0000:0000:0000',
+      '::1': '0000:0000:0000:0000:0000:0000:0000:0001',
+      '1::1': '0001:0000:0000:0000:0000:0000:0000:0001',
     }
 
     for test_arg, expected in test_values.items():
       self.assertEquals(expected, stem.util.connection.expand_ipv6_address(test_arg))
 
-    self.assertRaises(ValueError, stem.util.connection.expand_ipv6_address, "127.0.0.1")
+    self.assertRaises(ValueError, stem.util.connection.expand_ipv6_address, '127.0.0.1')
 
   def test_get_mask_ipv4(self):
     """
     Checks the get_mask_ipv4 function.
     """
 
-    self.assertEquals("255.255.255.255", stem.util.connection.get_mask_ipv4(32))
-    self.assertEquals("255.255.255.248", stem.util.connection.get_mask_ipv4(29))
-    self.assertEquals("255.255.254.0", stem.util.connection.get_mask_ipv4(23))
-    self.assertEquals("0.0.0.0", stem.util.connection.get_mask_ipv4(0))
+    self.assertEquals('255.255.255.255', stem.util.connection.get_mask_ipv4(32))
+    self.assertEquals('255.255.255.248', stem.util.connection.get_mask_ipv4(29))
+    self.assertEquals('255.255.254.0', stem.util.connection.get_mask_ipv4(23))
+    self.assertEquals('0.0.0.0', stem.util.connection.get_mask_ipv4(0))
 
     self.assertRaises(ValueError, stem.util.connection.get_mask_ipv4, -1)
     self.assertRaises(ValueError, stem.util.connection.get_mask_ipv4, 33)
@@ -385,9 +426,9 @@ class TestConnection(unittest.TestCase):
     Checks the get_mask_ipv6 function.
     """
 
-    self.assertEquals("FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF", stem.util.connection.get_mask_ipv6(128))
-    self.assertEquals("FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFE:0000", stem.util.connection.get_mask_ipv6(111))
-    self.assertEquals("0000:0000:0000:0000:0000:0000:0000:0000", stem.util.connection.get_mask_ipv6(0))
+    self.assertEquals('FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF', stem.util.connection.get_mask_ipv6(128))
+    self.assertEquals('FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFE:0000', stem.util.connection.get_mask_ipv6(111))
+    self.assertEquals('0000:0000:0000:0000:0000:0000:0000:0000', stem.util.connection.get_mask_ipv6(0))
 
     self.assertRaises(ValueError, stem.util.connection.get_mask_ipv6, -1)
     self.assertRaises(ValueError, stem.util.connection.get_mask_ipv6, 129)
@@ -397,13 +438,13 @@ class TestConnection(unittest.TestCase):
     Checks the _get_masked_bits function.
     """
 
-    self.assertEquals(32, stem.util.connection._get_masked_bits("255.255.255.255"))
-    self.assertEquals(29, stem.util.connection._get_masked_bits("255.255.255.248"))
-    self.assertEquals(23, stem.util.connection._get_masked_bits("255.255.254.0"))
-    self.assertEquals(0, stem.util.connection._get_masked_bits("0.0.0.0"))
+    self.assertEquals(32, stem.util.connection._get_masked_bits('255.255.255.255'))
+    self.assertEquals(29, stem.util.connection._get_masked_bits('255.255.255.248'))
+    self.assertEquals(23, stem.util.connection._get_masked_bits('255.255.254.0'))
+    self.assertEquals(0, stem.util.connection._get_masked_bits('0.0.0.0'))
 
-    self.assertRaises(ValueError, stem.util.connection._get_masked_bits, "blarg")
-    self.assertRaises(ValueError, stem.util.connection._get_masked_bits, "255.255.0.255")
+    self.assertRaises(ValueError, stem.util.connection._get_masked_bits, 'blarg')
+    self.assertRaises(ValueError, stem.util.connection._get_masked_bits, '255.255.0.255')
 
   def test_get_address_binary(self):
     """
@@ -411,18 +452,18 @@ class TestConnection(unittest.TestCase):
     """
 
     test_values = {
-      "0.0.0.0": "00000000000000000000000000000000",
-      "1.2.3.4": "00000001000000100000001100000100",
-      "127.0.0.1": "01111111000000000000000000000001",
-      "255.255.255.255": "11111111111111111111111111111111",
-      "::": "0" * 128,
-      "::1": ("0" * 127) + "1",
-      "1::1": "0000000000000001" + ("0" * 111) + "1",
-      "2001:db8::ff00:42:8329": "00100000000000010000110110111000000000000000000000000000000000000000000000000000111111110000000000000000010000101000001100101001",
+      '0.0.0.0': '00000000000000000000000000000000',
+      '1.2.3.4': '00000001000000100000001100000100',
+      '127.0.0.1': '01111111000000000000000000000001',
+      '255.255.255.255': '11111111111111111111111111111111',
+      '::': '0' * 128,
+      '::1': ('0' * 127) + '1',
+      '1::1': '0000000000000001' + ('0' * 111) + '1',
+      '2001:db8::ff00:42:8329': '00100000000000010000110110111000000000000000000000000000000000000000000000000000111111110000000000000000010000101000001100101001',
     }
 
     for test_arg, expected in test_values.items():
       self.assertEquals(expected, stem.util.connection._get_address_binary(test_arg))
 
-    self.assertRaises(ValueError, stem.util.connection._get_address_binary, "")
-    self.assertRaises(ValueError, stem.util.connection._get_address_binary, "blarg")
+    self.assertRaises(ValueError, stem.util.connection._get_address_binary, '')
+    self.assertRaises(ValueError, stem.util.connection._get_address_binary, 'blarg')
