@@ -25,76 +25,82 @@ class TestStrTools(unittest.TestCase):
     self.assertEquals('Hello\tworld', str_tools._to_camel_case('hello\tWORLD'))
     self.assertEquals('Hello\t\tWorld', str_tools._to_camel_case('hello__world', '_', '\t'))
 
-  def test_get_size_label(self):
+  def test_crop(self):
+    # test the pydoc examples
+    self.assertEquals('This is a looo...', str_tools.crop('This is a looooong message', 17))
+    self.assertEquals('This is a...', str_tools.crop('This is a looooong message', 12))
+    self.assertEquals('', str_tools.crop('This is a looooong message', 3))
+
+  def test_size_label(self):
     """
-    Checks the get_size_label() function.
+    Checks the size_label() function.
     """
 
     # test the pydoc examples
-    self.assertEquals('1 MB', str_tools.get_size_label(2000000))
-    self.assertEquals('1.02 KB', str_tools.get_size_label(1050, 2))
-    self.assertEquals('1.025 Kilobytes', str_tools.get_size_label(1050, 3, True))
+    self.assertEquals('1 MB', str_tools.size_label(2000000))
+    self.assertEquals('1.02 KB', str_tools.size_label(1050, 2))
+    self.assertEquals('1.025 Kilobytes', str_tools.size_label(1050, 3, True))
 
-    self.assertEquals('0 B', str_tools.get_size_label(0))
-    self.assertEquals('0 Bytes', str_tools.get_size_label(0, is_long = True))
-    self.assertEquals('0.00 B', str_tools.get_size_label(0, 2))
-    self.assertEquals('-10 B', str_tools.get_size_label(-10))
-    self.assertEquals('80 b', str_tools.get_size_label(10, is_bytes = False))
-    self.assertEquals('-1 MB', str_tools.get_size_label(-2000000))
+    self.assertEquals('0 B', str_tools.size_label(0))
+    self.assertEquals('0 Bytes', str_tools.size_label(0, is_long = True))
+    self.assertEquals('0.00 B', str_tools.size_label(0, 2))
+    self.assertEquals('-10 B', str_tools.size_label(-10))
+    self.assertEquals('80 b', str_tools.size_label(10, is_bytes = False))
+    self.assertEquals('-1 MB', str_tools.size_label(-2000000))
 
     # checking that we round down
-    self.assertEquals('23.43 Kb', str_tools.get_size_label(3000, 2, is_bytes = False))
+    self.assertEquals('23.43 Kb', str_tools.size_label(3000, 2, is_bytes = False))
 
-    self.assertRaises(TypeError, str_tools.get_size_label, None)
-    self.assertRaises(TypeError, str_tools.get_size_label, 'hello world')
+    self.assertRaises(TypeError, str_tools.size_label, None)
+    self.assertRaises(TypeError, str_tools.size_label, 'hello world')
 
-  def test_get_time_label(self):
+  def test_time_label(self):
     """
-    Checks the get_time_label() function.
+    Checks the time_label() function.
     """
 
     # test the pydoc examples
-    self.assertEquals('2h', str_tools.get_time_label(10000))
-    self.assertEquals('1.0 minute', str_tools.get_time_label(61, 1, True))
-    self.assertEquals('1.01 minutes', str_tools.get_time_label(61, 2, True))
+    self.assertEquals('2h', str_tools.time_label(10000))
+    self.assertEquals('1.0 minute', str_tools.time_label(61, 1, True))
+    self.assertEquals('1.01 minutes', str_tools.time_label(61, 2, True))
 
-    self.assertEquals('0s', str_tools.get_time_label(0))
-    self.assertEquals('0 seconds', str_tools.get_time_label(0, is_long = True))
-    self.assertEquals('0.00s', str_tools.get_time_label(0, 2))
-    self.assertEquals('-10s', str_tools.get_time_label(-10))
+    self.assertEquals('0s', str_tools.time_label(0))
+    self.assertEquals('0 seconds', str_tools.time_label(0, is_long = True))
+    self.assertEquals('0.00s', str_tools.time_label(0, 2))
+    self.assertEquals('-10s', str_tools.time_label(-10))
 
-    self.assertRaises(TypeError, str_tools.get_time_label, None)
-    self.assertRaises(TypeError, str_tools.get_time_label, 'hello world')
+    self.assertRaises(TypeError, str_tools.time_label, None)
+    self.assertRaises(TypeError, str_tools.time_label, 'hello world')
 
-  def test_get_time_labels(self):
+  def test_time_labels(self):
     """
-    Checks the get_time_labels() function.
+    Checks the time_labels() function.
     """
 
     # test the pydoc examples
-    self.assertEquals(['6m', '40s'], str_tools.get_time_labels(400))
-    self.assertEquals(['1 hour', '40 seconds'], str_tools.get_time_labels(3640, True))
+    self.assertEquals(['6m', '40s'], str_tools.time_labels(400))
+    self.assertEquals(['1 hour', '40 seconds'], str_tools.time_labels(3640, True))
 
-    self.assertEquals([], str_tools.get_time_labels(0))
-    self.assertEquals(['-10s'], str_tools.get_time_labels(-10))
+    self.assertEquals([], str_tools.time_labels(0))
+    self.assertEquals(['-10s'], str_tools.time_labels(-10))
 
-    self.assertRaises(TypeError, str_tools.get_time_labels, None)
-    self.assertRaises(TypeError, str_tools.get_time_labels, 'hello world')
+    self.assertRaises(TypeError, str_tools.time_labels, None)
+    self.assertRaises(TypeError, str_tools.time_labels, 'hello world')
 
-  def test_get_short_time_label(self):
+  def test_short_time_label(self):
     """
-    Checks the get_short_time_label() function.
+    Checks the short_time_label() function.
     """
 
     # test the pydoc examples
-    self.assertEquals('01:51', str_tools.get_short_time_label(111))
-    self.assertEquals('6-07:08:20', str_tools.get_short_time_label(544100))
+    self.assertEquals('01:51', str_tools.short_time_label(111))
+    self.assertEquals('6-07:08:20', str_tools.short_time_label(544100))
 
-    self.assertEquals('00:00', str_tools.get_short_time_label(0))
+    self.assertEquals('00:00', str_tools.short_time_label(0))
 
-    self.assertRaises(TypeError, str_tools.get_short_time_label, None)
-    self.assertRaises(TypeError, str_tools.get_short_time_label, 'hello world')
-    self.assertRaises(ValueError, str_tools.get_short_time_label, -5)
+    self.assertRaises(TypeError, str_tools.short_time_label, None)
+    self.assertRaises(TypeError, str_tools.short_time_label, 'hello world')
+    self.assertRaises(ValueError, str_tools.short_time_label, -5)
 
   def test_parse_short_time_label(self):
     """
